@@ -1,20 +1,9 @@
-/*************************************************************************
- *  Copyright (C) 2018 by Caio Carvalho <caiojcarvalho@gmail.com>        *
- *  Copyright (C) 2018 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2018 Caio Jordão Carvalho <caiojcarvalho@gmail.com>
+    SPDX-FileCopyrightText: 2018-2019 Andrius Štikonas <andrius@stikonas.eu>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #ifndef KPMCORE_SMARTDISKINFORMATION_H
 #define KPMCORE_SMARTDISKINFORMATION_H
@@ -30,7 +19,7 @@ class SmartAttributeParsedData;
 
     It includes a list with your SMART attributes.
 
-    @author Caio Carvalho <caiojcarvalho@gmail.com>
+    @author Caio Jordão Carvalho <caiojcarvalho@gmail.com>
 */
 class SmartDiskInformation
 {
